# Converted from table-file by table2r
# HPP Lattice gas
#
# J. Hardy, O. de Pazzis, and Y. Pomeau (1973) J. Math. Phys. 14, 470.
# 
# The earliest lattice gas model. Later made obsolete by the FHP gas on
# a hexagonal lattice, which has better physical properties.
# 
# States following http://pages.cs.wisc.edu/~wylie/doc/PhD_thesis.pdf
# 
# Each cell can contain up to 4 particles, each moving in one of the four directions.
# Outgoing directions SENW map onto 4 bits, so W=0001=1, SEW=1101=13, etc.
# Next state is simply the collected inputs, in most cases.
# The exceptions are 5 (EW) and 10 (NS) which get swapped (bounce on collision).
# 
# To make the gas useful in Golly's infinite area, I've added reflecting boundary
# states, 16-31. These work in the same way as gas particles (collecting inputs)
# but reverse their direction. Contact: Tim Hutton <tim.hutton@gmail.com>
#
# Sink boundary: (or you can vent to the outside but this way is neater)
# 32
# Source boundary: (haven't really worked out how to use this well yet)
# 33
#
# The HPP gas can also be run using the Margolus-neighborhood emulator in
# Golly (see e.g. Other-Rules/Margolus/BBM.rle) but this CA is neater.

states 34
nosymmetries

# any of the gas states: 0123456789ABCDEF
# any of the reflecting boundary states: GHIJKLMNOPQRSTUV
# has an outgoing south particle: 89ABCDEFOPQRSTUVX
# doesn't have an outgoing south particle: 01234567GHIJKLMNW
# has an outgoing east particle: 4567CDEFKLMNSTUVX
# doesn't have an outgoing east particle: 012389ABGHIJOPQRW
# has an outgoing north particle: 2367ABEFIJMNQRUVX
# doesn't have an outgoing north particle: 014589CDGHKLOPSTW
# has an outgoing west particle: 13579BDFHJLNPRTVX
# doesn't have an outgoing north particle: 02468ACEGIKMOQSUW

# straightforward transport (no interactions) except 5 and 10 which are swapped
[0123456789ABCDEF][01234567GHIJKLMNW][02468ACEGIKMOQSUW][014589CDGHKLOPSTW][012389ABGHIJOPQRW]0
[0123456789ABCDEF][01234567GHIJKLMNW][13579BDFHJLNPRTVX][014589CDGHKLOPSTW][012389ABGHIJOPQRW]1
[0123456789ABCDEF][01234567GHIJKLMNW][02468ACEGIKMOQSUW][2367ABEFIJMNQRUVX][012389ABGHIJOPQRW]2
[0123456789ABCDEF][01234567GHIJKLMNW][13579BDFHJLNPRTVX][2367ABEFIJMNQRUVX][012389ABGHIJOPQRW]3
[0123456789ABCDEF][01234567GHIJKLMNW][02468ACEGIKMOQSUW][014589CDGHKLOPSTW][4567CDEFKLMNSTUVX]4
[0123456789ABCDEF][01234567GHIJKLMNW][13579BDFHJLNPRTVX][014589CDGHKLOPSTW][4567CDEFKLMNSTUVX]A
[0123456789ABCDEF][01234567GHIJKLMNW][02468ACEGIKMOQSUW][2367ABEFIJMNQRUVX][4567CDEFKLMNSTUVX]6
[0123456789ABCDEF][01234567GHIJKLMNW][13579BDFHJLNPRTVX][2367ABEFIJMNQRUVX][4567CDEFKLMNSTUVX]7
[0123456789ABCDEF][89ABCDEFOPQRSTUVX][02468ACEGIKMOQSUW][014589CDGHKLOPSTW][012389ABGHIJOPQRW]8
[0123456789ABCDEF][89ABCDEFOPQRSTUVX][13579BDFHJLNPRTVX][014589CDGHKLOPSTW][012389ABGHIJOPQRW]9
[0123456789ABCDEF][89ABCDEFOPQRSTUVX][02468ACEGIKMOQSUW][2367ABEFIJMNQRUVX][012389ABGHIJOPQRW]5
[0123456789ABCDEF][89ABCDEFOPQRSTUVX][13579BDFHJLNPRTVX][2367ABEFIJMNQRUVX][012389ABGHIJOPQRW]B
[0123456789ABCDEF][89ABCDEFOPQRSTUVX][02468ACEGIKMOQSUW][014589CDGHKLOPSTW][4567CDEFKLMNSTUVX]C
[0123456789ABCDEF][89ABCDEFOPQRSTUVX][13579BDFHJLNPRTVX][014589CDGHKLOPSTW][4567CDEFKLMNSTUVX]D
[0123456789ABCDEF][89ABCDEFOPQRSTUVX][02468ACEGIKMOQSUW][2367ABEFIJMNQRUVX][4567CDEFKLMNSTUVX]E
[0123456789ABCDEF][89ABCDEFOPQRSTUVX][13579BDFHJLNPRTVX][2367ABEFIJMNQRUVX][4567CDEFKLMNSTUVX]F

# reflecting boundaries:
[GHIJKLMNOPQRSTUV][01234567GHIJKLMNW][02468ACEGIKMOQSUW][014589CDGHKLOPSTW][012389ABGHIJOPQRW]G
[GHIJKLMNOPQRSTUV][01234567GHIJKLMNW][02468ACEGIKMOQSUW][014589CDGHKLOPSTW][4567CDEFKLMNSTUVX]H
[GHIJKLMNOPQRSTUV][89ABCDEFOPQRSTUVX][02468ACEGIKMOQSUW][014589CDGHKLOPSTW][012389ABGHIJOPQRW]I
[GHIJKLMNOPQRSTUV][89ABCDEFOPQRSTUVX][02468ACEGIKMOQSUW][014589CDGHKLOPSTW][4567CDEFKLMNSTUVX]J
[GHIJKLMNOPQRSTUV][01234567GHIJKLMNW][13579BDFHJLNPRTVX][014589CDGHKLOPSTW][012389ABGHIJOPQRW]K
[GHIJKLMNOPQRSTUV][01234567GHIJKLMNW][13579BDFHJLNPRTVX][014589CDGHKLOPSTW][4567CDEFKLMNSTUVX]L
[GHIJKLMNOPQRSTUV][89ABCDEFOPQRSTUVX][13579BDFHJLNPRTVX][014589CDGHKLOPSTW][012389ABGHIJOPQRW]M
[GHIJKLMNOPQRSTUV][89ABCDEFOPQRSTUVX][13579BDFHJLNPRTVX][014589CDGHKLOPSTW][4567CDEFKLMNSTUVX]N
[GHIJKLMNOPQRSTUV][01234567GHIJKLMNW][02468ACEGIKMOQSUW][2367ABEFIJMNQRUVX][012389ABGHIJOPQRW]O
[GHIJKLMNOPQRSTUV][01234567GHIJKLMNW][02468ACEGIKMOQSUW][2367ABEFIJMNQRUVX][4567CDEFKLMNSTUVX]P
[GHIJKLMNOPQRSTUV][89ABCDEFOPQRSTUVX][02468ACEGIKMOQSUW][2367ABEFIJMNQRUVX][012389ABGHIJOPQRW]Q
[GHIJKLMNOPQRSTUV][89ABCDEFOPQRSTUVX][02468ACEGIKMOQSUW][2367ABEFIJMNQRUVX][4567CDEFKLMNSTUVX]R
[GHIJKLMNOPQRSTUV][01234567GHIJKLMNW][13579BDFHJLNPRTVX][2367ABEFIJMNQRUVX][012389ABGHIJOPQRW]S
[GHIJKLMNOPQRSTUV][01234567GHIJKLMNW][13579BDFHJLNPRTVX][2367ABEFIJMNQRUVX][4567CDEFKLMNSTUVX]T
[GHIJKLMNOPQRSTUV][89ABCDEFOPQRSTUVX][13579BDFHJLNPRTVX][2367ABEFIJMNQRUVX][012389ABGHIJOPQRW]U
[GHIJKLMNOPQRSTUV][89ABCDEFOPQRSTUVX][13579BDFHJLNPRTVX][2367ABEFIJMNQRUVX][4567CDEFKLMNSTUVX]V
